Stan Math Library: Namespace Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

- All
- Functions
- Variables
- Typedefs

- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- u
- v
- w

Here is a list of all namespace members with links to the namespace documentation for each member:

### - d -

- decouple_ode_states() : stan::math
- derivative() : stan::math
- determinant() : stan::math
- diag_matrix() : stan::math
- diag_post_multiply() : stan::math
- diag_pre_multiply() : stan::math
- diagonal() : stan::math
- digamma() : stan::math
- dims() : stan::math
- dirichlet_log() : stan::math
- dirichlet_rng() : stan::math
- dist() : stan::math
- distance() : stan::math
- divide() : stan::math
- do_lkj_constant() : stan::math
- domain_error() : stan::math
- domain_error_vec() : stan::math
- dot() : stan::math
- dot_product() : stan::math
- dot_self() : stan::math
- double_exponential_ccdf_log() : stan::math
- double_exponential_cdf() : stan::math
- double_exponential_cdf_log() : stan::math
- double_exponential_log() : stan::math
- double_exponential_rng() : stan::math

[ Stan Home Page ] © 2011–2016, Stan Development Team.